# Copyright (C) Red Hat Inc.
#
# resultsdb_conventions is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Author:   Adam Williamson <awilliam@redhat.com>

# these are all kinda inappropriate for pytest patterns
# pylint: disable=old-style-class, no-init, protected-access, no-self-use, unused-argument

"""Tests for the helper functions."""

from __future__ import unicode_literals
from __future__ import print_function

# external imports
import uuid

# 'internal' imports
from resultsdb_conventions import helpers


class TestHelpers:
    """Tests for the helper functions."""

    def test_uuid_namespace_default(self):
        """Test the uuid_namespace helper works correctly with the
        default namespace (which should be uuid.NAMESPACE_DNS).
        """
        # this is a native 'str' in py2 and py3
        res = helpers.uuid_namespace(str('test'))
        # this is a unicode in py2, native 'str' in py3
        res2 = helpers.uuid_namespace('test')
        assert type(res) is uuid.UUID
        assert str(res) == '4be0643f-1d98-573b-97cd-ca98a65347dd'
        assert type(res2) is uuid.UUID
        assert str(res2) == '4be0643f-1d98-573b-97cd-ca98a65347dd'

    def test_uuid_unicode(self):
        """Test the uuid_namespace helper works with a name containing
        Unicode characters.
        """
        res = helpers.uuid_namespace('\u4500foobar')
        assert type(res) is uuid.UUID
        assert str(res) == 'a050b517-6677-5119-9a77-2d26bbf30507'

    def test_uuid_namespace(self):
        """Test the uuid_namespace helper works with a specified
        namespace.
        """
        ns = helpers.uuid_namespace('test')
        res = helpers.uuid_namespace('test', ns)
        assert type(res) is uuid.UUID
        assert str(res) == '18ce9adf-9d2e-57a3-9374-076282f3d95b'

# vim: set textwidth=120 ts=8 et sw=4:



# Copyright (C) Red Hat Inc.
#
# resultsdb_conventions is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Author:   Adam Williamson <awilliam@redhat.com>

"""Fedora-specific conventions."""

from __future__ import unicode_literals
from __future__ import print_function

# stdlib imports
import logging

# external imports
from cached_property import cached_property
import fedfind.exceptions
import fedfind.release

# internal imports
from .base import Result
from .prodmd import (ProductmdComposeResult, ProductmdImageResult)

# pylint:disable=invalid-name
logger = logging.getLogger(__name__)


class FedoraComposeResult(ProductmdComposeResult):
    """Result from a test of a Fedora compose in general (not related
    to a specific deliverable). Functionally, just adds a URL to the
    compose group. Expects compose discovery from the compose ID, via
    fedfind: cid is the compose ID. May raise ValueError directly or
    via get_release.
    """
    def __init__(self, cid, *args, **kwargs):
        self.cid = cid
        composeinfo = self.ffrel.metadata['composeinfo']
        super(FedoraComposeResult, self).__init__(composeinfo, *args, **kwargs)
        self.conventions.append('fedora.compose')

    def default_groups(self):
        super(FedoraComposeResult, self).default_groups()
        # update the existing compose group with a URL
        try:
            rel = fedfind.release.get_release(cid=self.cid)
            self.add_group('compose', self.cid, ref_url=self.ffrel.location)
        except (ValueError, fedfind.exceptions.FedfindError):
            logger.warning("fedfind found no release for compose ID %s, compose group will have no URL", self.cid)
            return

    @cached_property
    def ffrel(self):
        """Cached instance of fedfind release object."""
        return fedfind.release.get_release(cid=self.cid)


class FedoraImageResult(ProductmdImageResult, FedoraComposeResult):
    """Result from testing a specific image from a Fedora compose.
    filename is the image filename. cid is the compose ID (explicitly
    taken here as we need to use it before calling the parent class
    __init__). If imgdict is not provided, will use fedfind to find it
    from the filename.
    """
    def __init__(self, filename, cid, imgdict=None, *args, **kwargs):
        self.cid = cid
        self.filename = filename
        if not imgdict:
            imgdict = self.ffimg
        super(FedoraImageResult, self).__init__(imgdict, cid, *args, **kwargs)
        self.filename = filename
        self.conventions.append('fedora.image')

    @cached_property
    def ffimg(self):
        """Cached instance of fedfind image dict."""
        try:
            # this just gets the first image found by the expression,
            # we expect there to be maximum one (per dgilmore, image
            # filenames are unique at least until koji namespacing)
            return next(_img for _img in self.ffrel.all_images if _img['path'].endswith(self.filename))
        except StopIteration:
            # this happens if the expression find *no* images
            raise ValueError("Can't find image {0} in release {1}".format(self.filename, self.cid))


class FedoraBodhiResult(Result):
    """Result from testing a Fedora Bodhi update. update is the
    update ID.
    """
    def __init__(self, update, *args, **kwargs):
        self.update = update
        super(FedoraBodhiResult, self).__init__(*args, **kwargs)
        self.conventions.append('fedora.bodhi')
        self.extradata.update({
            'item': self.update,
            'type': 'bodhi_update',
        })

    def default_groups(self):
        super(FedoraBodhiResult, self).default_groups()
        url = 'https://bodhi.fedoraproject.org/updates/{0}'.format(self.update)
        self.add_group('bodhi', self.update, ref_url=url)
        if self.source:
            self.add_group(self.source, self.update)

# vim: set textwidth=120 ts=8 et sw=4:



# Copyright (C) Red Hat Inc.
#
# resultsdb_conventions is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Author:   Adam Williamson <awilliam@redhat.com>

"""The core Result class lives here."""

from __future__ import unicode_literals
from __future__ import print_function

# stdlib imports
import logging

# internal imports
from . import helpers

# pylint:disable=invalid-name
logger = logging.getLogger(__name__)

class Result(object):
    """Base class for a single result. The signature follows the API
    create_result class as closely as possible. outcome is the actual
    result of the test ('PASSED', 'FAILED' etc.) tc_name is the test
    case name. groups may be an iterable of UUID strings or ResultsDB
    group instances; if set, the Result will be added to all the
    groups. note is the freeform text note. ref_url is the URL for
    this specific result, tc_url is the general URL for the testcase.
    source is the source of the result - something like 'openqa' or
    'autocloud'.
    """
    def __init__(self, outcome, tc_name, groups=None, note='', ref_url='', tc_url='', source=''):
        self.outcome = outcome
        self.tc_name = tc_name
        self.note = note
        self.ref_url = ref_url
        self.tc_url = tc_url
        self.source = source
        self.extradata = {}
        self.groups = []
        if groups:
            self.groups.extend(groups)
        self.conventions = ['result']

    @property
    def testcase_object(self):
        """The testcase object for this result."""
        return {
            "name": self.tc_name,
            "ref_url": self.tc_url,
        }

    def validate(self):
        """Check if the contents of the result are valid. We do not
        actually do any validation at this level - we cannot logically
        declare any conventions beyond what ResultsDB will accept, and
        the API will refuse any flat out invalid result.
        """
        pass

    def default_extradata(self):
        """Produce and include or update the meta.conventions item,
        listing the conventions the result complies with. If we have a
        source, add it too.
        """
        # this is called meta.conventions because it's metametadata:
        # it's information about the metadata...
        self.extradata['meta.conventions'] = ' '.join(self.conventions)
        if self.source:
            extradata = {'source': self.source}
            # doing things this way around means we don't override
            # existing values, only add new ones
            extradata.update(self.extradata)
            self.extradata = extradata

    def add_group(self, namespace, group_name, **extraparams):
        """Create a group dict and add it to the instance group list,
        using the normal convention for creating ResultsDB groups.
        The description of the group will be 'namespace.group' and
        the UUID is created from those values in a kinda agreed-upon
        way. Any extra params for the group can be passed in. If there
        is already a group with the same namespace and name, its dict
        will be updated with the passed extraparams; this lets you
        modify an existing group by calling add_group again with the
        same namespace and group_name.
        """
        uuidns = helpers.uuid_namespace(namespace)
        groupdict = {
            'uuid': str(helpers.uuid_namespace(group_name, uuidns)),
            'description': '.'.join((namespace, group_name))
        }
        groupdict.update(**extraparams)
        for curgroup in self.groups:
            try:
                if curgroup['description'] == groupdict['description']:
                    curgroup.update(**extraparams)
                    return
            except TypeError:
                # this is what we get if curgroup is a str not a dict
                pass
        # only get here if no existing group matches
        self.groups.append(groupdict)

    def default_groups(self):
        """If we have a source, add a generic source group."""
        # NOTE: we could add a generic test case group, like there is
        # for Taskotron results, but I don't think it's any use
        if self.source:
            self.add_group('source', self.source)

    def report(self, rdbinstance, default_extradata=True, default_groups=True):
        """Report this result to ResultsDB. rdbinstance is an instance
        of ResultsDBapi. May pass through an exception raised by the
        API instance `create_result` method.
        """
        self.validate()
        if default_extradata:
            self.default_extradata()
        if default_groups:
            self.default_groups()
        logger.debug("Result: %s", self.outcome)
        logger.debug("Testcase object: %s", self.testcase_object)
        logger.debug("Groups: %s", self.groups)
        logger.debug("Job link (ref_url): %s", self.ref_url)
        logger.debug("Extradata: %s", self.extradata)
        if rdbinstance:
            return rdbinstance.create_result(outcome=self.outcome, testcase=self.testcase_object, groups=self.groups,
                                             note=self.note, ref_url=self.ref_url, **self.extradata)

# vim: set textwidth=120 ts=8 et sw=4:



# Copyright (C) Red Hat Inc.
#
# resultsdb_conventions is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Author:   Adam Williamson <awilliam@redhat.com>

# these are all kinda inappropriate for pytest patterns
# pylint: disable=old-style-class, no-init, protected-access, no-self-use, unused-argument

"""Tests for the Fedora classes."""

from __future__ import unicode_literals
from __future__ import print_function

# external imports
import fedfind.release
import mock

# 'internal' imports
from resultsdb_conventions.fedora import (FedoraImageResult, FedoraBodhiResult)

# fedfind metadata dict used to avoid a round trip to get the real one.
METADATA01 = {
    "composeinfo": {
        "header": {
            "type": "productmd.composeinfo",
            "version": "1.2"
        },
        "payload": {
            "compose": {
                "date": "20170131",
                "id": "Fedora-Rawhide-20170131.n.1",
                "respin": 1,
                "type": "nightly"
            },
            "release": {
                "internal": False,
                "name": "Fedora",
                "short": "Fedora",
                "type": "ga",
                "version": "Rawhide"
            },
        },
    },
}

# fedfind image dict we use to avoid a round trip to get the real one.
FFIMG01 = {
    'variant': 'Server',
    'checksums': {'sha256': 'a7cd606a44b40a3e82cc71079f80b6928e155e112d0788e5cc80a6f3d4cbe6a3'},
    'arch': 'x86_64',
    'path': 'Server/x86_64/iso/Fedora-Server-dvd-x86_64-Rawhide-20170131.n.1.iso',
    'bootable': True,
    'size': 3009413120,
    'implant_md5': '962ec7863a78607ba4e3fc7cda01cc46',
    'mtime': 1485870969,
    'disc_count': 1,
    'format': 'iso',
    'volume_id': 'Fedora-S-dvd-x86_64-rawh',
    'subvariant': 'Server',
    'disc_number': 1,
    'type': 'dvd'
}


class TestFedora:
    """Fedora class tests."""

    @mock.patch.object(FedoraImageResult, 'ffimg', FFIMG01)
    @mock.patch.object(fedfind.release.RawhideNightly, 'metadata', METADATA01)
    def test_fedoraimage_basic(self):
        """This is just a pretty basic overall test that instantiates
        the most complex class, produces a result and checks its
        properties.
        """
        res = FedoraImageResult(
            cid='Fedora-Rawhide-20170131.n.1',
            filename='Fedora-Server-dvd-x86_64-Rawhide-20170131.n.1.iso',
            outcome='PASSED',
            tc_name='compose.some.test',
            note='note here',
            ref_url='https://www.job.link/',
            tc_url='https://www.test.case/',
            source='testsource' 
        )
        # Report to a MagicMock, so we can check create_result args
        fakeapi = mock.MagicMock()
        res.report(fakeapi)

        # basic attribute checks
        assert res.outcome == 'PASSED'
        assert res.tc_name == 'compose.some.test'
        assert res.note == 'note here'
        assert res.ref_url == 'https://www.job.link/'
        assert res.tc_url == 'https://www.test.case/'
        assert res.source == 'testsource'

        # check the testcase object
        assert res.testcase_object == {
            'name': 'compose.some.test',
            'ref_url': 'https://www.test.case/',
        }

        # check the extradata
        assert res.extradata == {
            'item': 'Fedora-Server-dvd-x86_64-Rawhide-20170131.n.1.iso',
            'meta.conventions': 'result productmd.compose fedora.compose productmd.image fedora.image',
            'productmd.compose.date': '20170131',
            'productmd.compose.id': 'Fedora-Rawhide-20170131.n.1',
            'productmd.compose.name': 'Fedora',
            'productmd.compose.short': 'Fedora',
            'productmd.compose.respin': 1,
            'productmd.compose.type': 'nightly',
            'productmd.compose.version': 'Rawhide',
            'productmd.image.arch': 'x86_64',
            'productmd.image.disc_number': '1',
            'productmd.image.format': 'iso',
            'productmd.image.subvariant': 'Server',
            'productmd.image.type': 'dvd',
            'source': 'testsource',
            'type': 'compose'
        }

        # check the groups
        assert res.groups == [
            {
                'description': 'source.testsource',
                'uuid': 'ddf8c194-5e34-50ec-b0e8-205c63b0dfc1'
            },
            {
                'description': 'compose.Fedora-Rawhide-20170131.n.1',
                'ref_url': 'https://kojipkgs.fedoraproject.org/compose/rawhide/Fedora-Rawhide-20170131.n.1/compose',
                'uuid': '8f6a8786-7b02-5ec0-9ac4-086ef3e33515'
            },
            {
                'description': 'testsource.Fedora-Rawhide-20170131.n.1',
                'uuid': 'b42e8fbf-b74a-5ee3-8d1d-e59e17220fce'
            },
            {
                'description': 'image.server.dvd.iso.x86_64.1',
                'uuid': '65b7f973-d87b-5008-a6e7-f431155b9a00'
            },
            {
                'description': 'testsource.server.dvd.iso.x86_64.1',
                'uuid': 'f5969a48-5c55-5d16-abb8-a94d54aacf22'
            }
        ]

    def test_fedorabodhi(self):
        """Check the expected properties of a FedoraBodhiResult."""
        res = FedoraBodhiResult(
            update='FEDORA-2017-e6d7184200',
            outcome='PASSED',
            tc_name='update.some.test',
            note='note here',
            ref_url='https://www.job.link/',
            tc_url='https://www.test.case/',
            source='testsource'
        )
        # Report to a MagicMock, so we can check create_result args
        fakeapi = mock.MagicMock()
        res.report(fakeapi)

        # basic attribute checks
        assert res.outcome == 'PASSED'
        assert res.tc_name == 'update.some.test'
        assert res.note == 'note here'
        assert res.ref_url == 'https://www.job.link/'
        assert res.tc_url == 'https://www.test.case/'
        assert res.source == 'testsource'

        # check the testcase object
        assert res.testcase_object == {
            'name': 'update.some.test',
            'ref_url': 'https://www.test.case/',
        }

        # check the extradata
        assert res.extradata == {
            'item': 'FEDORA-2017-e6d7184200',
            'meta.conventions': 'result fedora.bodhi',
            'source': 'testsource',
            'type': 'bodhi_update'
        }

        # check the groups
        assert res.groups == [
            {
                'description': 'source.testsource',
                'uuid': 'ddf8c194-5e34-50ec-b0e8-205c63b0dfc1'
            },
            {
                'description': 'bodhi.FEDORA-2017-e6d7184200',
                'ref_url': 'https://bodhi.fedoraproject.org/updates/FEDORA-2017-e6d7184200',
                'uuid': 'c67605d5-0ff7-5f1e-91df-3d2ad094c902'
            },
            {
                'description': 'testsource.FEDORA-2017-e6d7184200',
                'uuid': 'd02731e7-46d3-545b-b355-3ff01ff62de1'
            },
        ]

# vim: set textwidth=120 ts=8 et sw=4:



# Copyright (C) Red Hat Inc.
#
# resultsdb_conventions is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Author:   Adam Williamson <awilliam@redhat.com>

"""Conventions for tests of items with productmd-style metadata."""

from __future__ import unicode_literals
from __future__ import print_function

# stdlib imports
import json
import logging

# external imports
import productmd.composeinfo

# internal imports
from .base import Result

# pylint:disable=invalid-name
logger = logging.getLogger(__name__)


class ProductmdComposeResult(Result):
    """Result from testing of a distribution compose with productmd
    style metadata. composeinfo must be the composeinfo metadata for
    the compose as a dict or a JSON string.
    """
    def __init__(self, composeinfo, *args, **kwargs):
        super(ProductmdComposeResult, self).__init__(*args, **kwargs)
        try:
            # already dict-ified
            composeinfo['header']
            self.composeinfo = composeinfo
        except TypeError:
            # JSON string
            self.composeinfo = json.loads(composeinfo)
        self.cid = self.composeinfo['payload']['compose']['id']
        # item is always the compose ID (unless subclass overrides)
        self.extradata.update({
            'item': self.cid,
            'type': 'compose',
        })
        self.conventions.append('productmd.compose')

    def default_extradata(self):
        """Add values from the metadata."""
        super(ProductmdComposeResult, self).default_extradata()
        extradata = {
            'productmd.compose.name': self.composeinfo['payload']['release']['name'],
            'productmd.compose.short': self.composeinfo['payload']['release']['short'],
            'productmd.compose.version': self.composeinfo['payload']['release']['version'],
            'productmd.compose.date': self.composeinfo['payload']['compose']['date'],
            'productmd.compose.type': self.composeinfo['payload']['compose']['type'],
            'productmd.compose.respin': self.composeinfo['payload']['compose']['respin'],
            'productmd.compose.id': self.cid,
        }
        extradata.update(self.extradata)
        self.extradata = extradata

    def default_groups(self):
        """Add to generic result group for this compose."""
        super(ProductmdComposeResult, self).default_groups()
        self.add_group('compose', self.cid)
        if self.source:
            self.add_group(self.source, self.cid)


class ProductmdImageResult(ProductmdComposeResult):
    """Result from testing a specific image in a distribution compose
    with productmd-style metadata. imgdict is the productmd image dict
    for the image.
    """
    def __init__(self, imgdict, *args, **kwargs):
        super(ProductmdImageResult, self).__init__(*args, **kwargs)
        self.imgdict = imgdict
        # assume / always used as path separator in productmd
        self.filename = imgdict['path'].split('/')[-1]
        # when we have an image, item is always the filename
        self.extradata.update({
            'item': self.filename,
        })
        self.conventions.append('productmd.image')

        # unique image identifier, per discussion at
        # https://pagure.io/pungi/issue/525 ; again, perhaps in the
        # long term this should be defined in productmd
        self.imgid = '.'.join((self.imgdict['subvariant'], self.imgdict['type'], self.imgdict['format'],
                               self.imgdict['arch'], str(self.imgdict['disc_number']))).lower()

    def default_extradata(self):
        """Populate extradata from compose ID and filename."""
        super(ProductmdImageResult, self).default_extradata()
        extradata = {
            'productmd.image.arch': self.imgdict['arch'],
            'productmd.image.disc_number': str(self.imgdict['disc_number']),
            'productmd.image.format': self.imgdict['format'],
            'productmd.image.subvariant': self.imgdict['subvariant'],
            'productmd.image.type': self.imgdict['type'],
        }
        extradata.update(self.extradata)
        self.extradata = extradata

    def default_groups(self):
        """Add to generic result group for this image."""
        super(ProductmdImageResult, self).default_groups()
        self.add_group('image', self.imgid)
        if self.source:
            # We cannot easily do a URL here, unless we start having
            # a store of 'known' sources and how URLs are built for
            # them, or using callbacks, or something. I think we might
            # just ask downstreams to get the group from the group
            # list and add the URL to it?
            self.add_group(self.source, self.imgid)

# vim: set textwidth=120 ts=8 et sw=4:



#!/usr/bin/env python
# Copyright (C) Red Hat, Inc.
#
# resultsdb_conventions is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Author: Adam Williamson <awilliam@redhat.com>

import os
import sys
from setuptools import setup, find_packages
from setuptools.command.test import test as TestCommand

class PyTest(TestCommand):
    user_options = [('pytest-args=', 'a', "Arguments to pass to py.test")]

    def initialize_options(self):
        TestCommand.initialize_options(self)
        self.pytest_args = ''
        self.test_suite = 'tests'

    def run_tests(self):
        #import here, cause outside the eggs aren't loaded
        import pytest
        errno = pytest.main(self.pytest_args.split())
        sys.exit(errno)


# From: https://github.com/pypa/pypi-legacy/issues/148
# Produce rst-formatted long_description if pypandoc is available (to
# look nice on pypi), otherwise just use the Markdown-formatted one
try:
    import pypandoc
    longdesc = pypandoc.convert('README.md', 'rst')
except ImportError:
    longdesc = open('README.md').read()


setup(
    name = "resultsdb_conventions",
    version = "2.0.3",
    packages = ['resultsdb_conventions'],
    author = "Adam Williamson",
    author_email = "awilliam@redhat.com",
    description = "Module for conveniently reporting to ResultsDB following conventions",
    license = "GPLv3+",
    keywords = "fedora rhel epel resultsdb test taskotron",
    url = "https://pagure.io/fedora-qa/resultsdb_conventions",
    install_requires = open('install.requires').read().splitlines(),
    tests_require = open('tests.requires').read().splitlines(),
    extras_require = {
        'fedora': ['fedfind'],
    },
    cmdclass = {'test': PyTest},
    long_description = longdesc,
    classifiers = [
        "Development Status :: 5 - Production/Stable",
        "Topic :: Utilities",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
    ],
)

# vim: set textwidth=120 ts=8 et sw=4:



# Copyright (C) Red Hat Inc.
#
# resultsdb_conventions is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Author:   Adam Williamson <awilliam@redhat.com>

"""Miscellaneous utility functions."""

from __future__ import unicode_literals
from __future__ import print_function

# stdlib imports
import logging
import uuid

# pylint:disable=invalid-name
logger = logging.getLogger(__name__)

def uuid_namespace(name, namespace=None):
    """Create a UUID using the provided name and namespace (or default
    DNS namespace), handling string type and encoding ickiness on both
    Py2 and Py3.
    """
    # so the deal here is the passed name may be a string or a unicode
    # in Python 2 (for Python 3 we assume it's a string), and what we
    # need back is a string - not a bytestring on Python 3, or a
    # unicode on Python 2, as uuid doesn't accept either - with non-
    # ASCII characters stripped (as uuid doesn't accept those either).
    # This magic formula seems to work and produce the same UUID on
    # both.
    if not namespace:
        namespace = uuid.NAMESPACE_DNS
    return uuid.uuid5(namespace, str(name.encode('ascii', 'ignore').decode()))

# vim: set textwidth=120 ts=8 et sw=4:
